@@ -46,15 +46,16 @@ typename covafill<scalartype_>::scalartype covafill<scalartype_>::calcNorm(vecto
 
 template<typename scalartype_>
 typename covafill<scalartype_>::scalartype covafill<scalartype_>::getWeight(vectortype x0, vectortype x1) const {
-  
+
   scalartype_ sqnorm = (Hinv * (x0 - x1).matrix()).squaredNorm();
-  scalartype_ res;
-  
-  if(sqnorm <= 1){
-    res = 1.0 - sqnorm;
-  }else{
-    res = 0;
-  }
+
+#ifdef USE_GAUSSIAN_KERNEL
+  scalartype res = exp(-0.5 * sqnorm);
+  #else
+  scalartype a = 1.0 - sqnorm;
+  scalartype b = 0.0;
+  scalartype res = 0.5 * (a + b + fabs(a-b));
+  #endif
   return res * detHinv;
 }
 
